==> com.liferay.dynamic.data.mapping.form.renderer-4.0.75.jar: META-INF/resources/js/store/actions/handleFieldRemoved.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@4.0.75/js/store/actions/handleFieldRemoved.es", ['module', 'exports', 'require', '../../util/visitors.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _visitors = require("../../util/visitors.es");

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  var _default = function _default(pages, name) {
    var visitor = new _visitors.PagesVisitor(pages);
    return visitor.mapColumns(function (column) {
      return _objectSpread({}, column, {
        fields: column.fields.filter(function (field) {
          return field.name !== name;
        })
      });
    });
  };

  exports["default"] = _default;
  //# sourceMappingURL=handleFieldRemoved.es.js.map
});
//# sourceMappingURL=handleFieldRemoved.es.js.map

==> com.liferay.dynamic.data.mapping.form.renderer-5.0.2.jar: META-INF/resources/js/store/actions/handleFieldRemoved.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@5.0.2/js/store/actions/handleFieldRemoved.es", ['module', 'exports', 'require', '../../util/visitors.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _visitors = require("../../util/visitors.es");

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(source, true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(source).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  var _default = function _default(pages, name) {
    var visitor = new _visitors.PagesVisitor(pages);
    return visitor.mapColumns(function (column) {
      return _objectSpread({}, column, {
        fields: column.fields.filter(function (field) {
          return field.name !== name;
        })
      });
    });
  };

  exports["default"] = _default;
  //# sourceMappingURL=handleFieldRemoved.es.js.map
});
//# sourceMappingURL=handleFieldRemoved.es.js.map
